import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { DatabaseMigrationServiceServiceException as __BaseException } from "./DatabaseMigrationServiceServiceException";
import {
  Certificate,
  ComputeConfig,
  Connection,
  DataMigration,
  DataProvider,
  DataProviderDescriptorDefinition,
  DataProviderSettings,
  DmsSslModeValue,
  DmsTransferSettings,
  DocDbSettings,
  DynamoDbSettings,
  ElasticsearchSettings,
  Endpoint,
  EventSubscription,
  Filter,
  GcpMySQLSettings,
  IBMDb2Settings,
  InstanceProfile,
  KafkaSettings,
  KerberosAuthenticationSettings,
  KinesisSettings,
  MicrosoftSQLServerSettings,
  MigrationProject,
  MigrationTypeValue,
  MongoDbSettings,
  MySQLSettings,
  NeptuneSettings,
  OracleSettings,
  PostgreSQLSettings,
  RecommendationSettings,
  RedisSettings,
  RedshiftSettings,
  RefreshSchemasStatus,
  Replication,
  ReplicationConfig,
  ReplicationEndpointTypeValue,
  ReplicationInstance,
  ReplicationSubnetGroup,
  ReplicationTask,
  ReplicationTaskAssessmentRun,
  S3Settings,
  SCApplicationAttributes,
  SourceDataSetting,
  SybaseSettings,
  TableStatistics,
  Tag,
  TargetDataSetting,
  TimestreamSettings,
} from "./models_0";
export interface DescribeReplicationTaskIndividualAssessmentsMessage {
  Filters?: Filter[] | undefined;
  MaxRecords?: number | undefined;
  Marker?: string | undefined;
}
export interface ReplicationTaskIndividualAssessment {
  ReplicationTaskIndividualAssessmentArn?: string | undefined;
  ReplicationTaskAssessmentRunArn?: string | undefined;
  IndividualAssessmentName?: string | undefined;
  Status?: string | undefined;
  ReplicationTaskIndividualAssessmentStartDate?: Date | undefined;
}
export interface DescribeReplicationTaskIndividualAssessmentsResponse {
  Marker?: string | undefined;
  ReplicationTaskIndividualAssessments?:
    | ReplicationTaskIndividualAssessment[]
    | undefined;
}
export interface DescribeReplicationTasksMessage {
  Filters?: Filter[] | undefined;
  MaxRecords?: number | undefined;
  Marker?: string | undefined;
  WithoutSettings?: boolean | undefined;
}
export interface DescribeReplicationTasksResponse {
  Marker?: string | undefined;
  ReplicationTasks?: ReplicationTask[] | undefined;
}
export interface DescribeSchemasMessage {
  EndpointArn: string | undefined;
  MaxRecords?: number | undefined;
  Marker?: string | undefined;
}
export interface DescribeSchemasResponse {
  Marker?: string | undefined;
  Schemas?: string[] | undefined;
}
export interface DescribeTableStatisticsMessage {
  ReplicationTaskArn: string | undefined;
  MaxRecords?: number | undefined;
  Marker?: string | undefined;
  Filters?: Filter[] | undefined;
}
export interface DescribeTableStatisticsResponse {
  ReplicationTaskArn?: string | undefined;
  TableStatistics?: TableStatistics[] | undefined;
  Marker?: string | undefined;
}
export declare const AssessmentReportType: {
  readonly CSV: "csv";
  readonly PDF: "pdf";
};
export type AssessmentReportType =
  (typeof AssessmentReportType)[keyof typeof AssessmentReportType];
export interface ExportMetadataModelAssessmentMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
  FileName?: string | undefined;
  AssessmentReportTypes?: AssessmentReportType[] | undefined;
}
export interface ExportMetadataModelAssessmentResultEntry {
  S3ObjectKey?: string | undefined;
  ObjectURL?: string | undefined;
}
export interface ExportMetadataModelAssessmentResponse {
  PdfReport?: ExportMetadataModelAssessmentResultEntry | undefined;
  CsvReport?: ExportMetadataModelAssessmentResultEntry | undefined;
}
export interface ImportCertificateMessage {
  CertificateIdentifier: string | undefined;
  CertificatePem?: string | undefined;
  CertificateWallet?: Uint8Array | undefined;
  Tags?: Tag[] | undefined;
}
export interface ImportCertificateResponse {
  Certificate?: Certificate | undefined;
}
export declare class InvalidCertificateFault extends __BaseException {
  readonly name: "InvalidCertificateFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidCertificateFault, __BaseException>
  );
}
export interface ListTagsForResourceMessage {
  ResourceArn?: string | undefined;
  ResourceArnList?: string[] | undefined;
}
export interface ListTagsForResourceResponse {
  TagList?: Tag[] | undefined;
}
export interface ModifyConversionConfigurationMessage {
  MigrationProjectIdentifier: string | undefined;
  ConversionConfiguration: string | undefined;
}
export interface ModifyConversionConfigurationResponse {
  MigrationProjectIdentifier?: string | undefined;
}
export interface ModifyDataMigrationMessage {
  DataMigrationIdentifier: string | undefined;
  DataMigrationName?: string | undefined;
  EnableCloudwatchLogs?: boolean | undefined;
  ServiceAccessRoleArn?: string | undefined;
  DataMigrationType?: MigrationTypeValue | undefined;
  SourceDataSettings?: SourceDataSetting[] | undefined;
  TargetDataSettings?: TargetDataSetting[] | undefined;
  NumberOfJobs?: number | undefined;
  SelectionRules?: string | undefined;
}
export interface ModifyDataMigrationResponse {
  DataMigration?: DataMigration | undefined;
}
export interface ModifyDataProviderMessage {
  DataProviderIdentifier: string | undefined;
  DataProviderName?: string | undefined;
  Description?: string | undefined;
  Engine?: string | undefined;
  ExactSettings?: boolean | undefined;
  Settings?: DataProviderSettings | undefined;
}
export interface ModifyDataProviderResponse {
  DataProvider?: DataProvider | undefined;
}
export interface ModifyEndpointMessage {
  EndpointArn: string | undefined;
  EndpointIdentifier?: string | undefined;
  EndpointType?: ReplicationEndpointTypeValue | undefined;
  EngineName?: string | undefined;
  Username?: string | undefined;
  Password?: string | undefined;
  ServerName?: string | undefined;
  Port?: number | undefined;
  DatabaseName?: string | undefined;
  ExtraConnectionAttributes?: string | undefined;
  CertificateArn?: string | undefined;
  SslMode?: DmsSslModeValue | undefined;
  ServiceAccessRoleArn?: string | undefined;
  ExternalTableDefinition?: string | undefined;
  DynamoDbSettings?: DynamoDbSettings | undefined;
  S3Settings?: S3Settings | undefined;
  DmsTransferSettings?: DmsTransferSettings | undefined;
  MongoDbSettings?: MongoDbSettings | undefined;
  KinesisSettings?: KinesisSettings | undefined;
  KafkaSettings?: KafkaSettings | undefined;
  ElasticsearchSettings?: ElasticsearchSettings | undefined;
  NeptuneSettings?: NeptuneSettings | undefined;
  RedshiftSettings?: RedshiftSettings | undefined;
  PostgreSQLSettings?: PostgreSQLSettings | undefined;
  MySQLSettings?: MySQLSettings | undefined;
  OracleSettings?: OracleSettings | undefined;
  SybaseSettings?: SybaseSettings | undefined;
  MicrosoftSQLServerSettings?: MicrosoftSQLServerSettings | undefined;
  IBMDb2Settings?: IBMDb2Settings | undefined;
  DocDbSettings?: DocDbSettings | undefined;
  RedisSettings?: RedisSettings | undefined;
  ExactSettings?: boolean | undefined;
  GcpMySQLSettings?: GcpMySQLSettings | undefined;
  TimestreamSettings?: TimestreamSettings | undefined;
}
export interface ModifyEndpointResponse {
  Endpoint?: Endpoint | undefined;
}
export interface ModifyEventSubscriptionMessage {
  SubscriptionName: string | undefined;
  SnsTopicArn?: string | undefined;
  SourceType?: string | undefined;
  EventCategories?: string[] | undefined;
  Enabled?: boolean | undefined;
}
export interface ModifyEventSubscriptionResponse {
  EventSubscription?: EventSubscription | undefined;
}
export interface ModifyInstanceProfileMessage {
  InstanceProfileIdentifier: string | undefined;
  AvailabilityZone?: string | undefined;
  KmsKeyArn?: string | undefined;
  PubliclyAccessible?: boolean | undefined;
  NetworkType?: string | undefined;
  InstanceProfileName?: string | undefined;
  Description?: string | undefined;
  SubnetGroupIdentifier?: string | undefined;
  VpcSecurityGroups?: string[] | undefined;
}
export interface ModifyInstanceProfileResponse {
  InstanceProfile?: InstanceProfile | undefined;
}
export interface ModifyMigrationProjectMessage {
  MigrationProjectIdentifier: string | undefined;
  MigrationProjectName?: string | undefined;
  SourceDataProviderDescriptors?:
    | DataProviderDescriptorDefinition[]
    | undefined;
  TargetDataProviderDescriptors?:
    | DataProviderDescriptorDefinition[]
    | undefined;
  InstanceProfileIdentifier?: string | undefined;
  TransformationRules?: string | undefined;
  Description?: string | undefined;
  SchemaConversionApplicationAttributes?: SCApplicationAttributes | undefined;
}
export interface ModifyMigrationProjectResponse {
  MigrationProject?: MigrationProject | undefined;
}
export interface ModifyReplicationConfigMessage {
  ReplicationConfigArn: string | undefined;
  ReplicationConfigIdentifier?: string | undefined;
  ReplicationType?: MigrationTypeValue | undefined;
  TableMappings?: string | undefined;
  ReplicationSettings?: string | undefined;
  SupplementalSettings?: string | undefined;
  ComputeConfig?: ComputeConfig | undefined;
  SourceEndpointArn?: string | undefined;
  TargetEndpointArn?: string | undefined;
}
export interface ModifyReplicationConfigResponse {
  ReplicationConfig?: ReplicationConfig | undefined;
}
export interface ModifyReplicationInstanceMessage {
  ReplicationInstanceArn: string | undefined;
  AllocatedStorage?: number | undefined;
  ApplyImmediately?: boolean | undefined;
  ReplicationInstanceClass?: string | undefined;
  VpcSecurityGroupIds?: string[] | undefined;
  PreferredMaintenanceWindow?: string | undefined;
  MultiAZ?: boolean | undefined;
  EngineVersion?: string | undefined;
  AllowMajorVersionUpgrade?: boolean | undefined;
  AutoMinorVersionUpgrade?: boolean | undefined;
  ReplicationInstanceIdentifier?: string | undefined;
  NetworkType?: string | undefined;
  KerberosAuthenticationSettings?: KerberosAuthenticationSettings | undefined;
}
export interface ModifyReplicationInstanceResponse {
  ReplicationInstance?: ReplicationInstance | undefined;
}
export declare class UpgradeDependencyFailureFault extends __BaseException {
  readonly name: "UpgradeDependencyFailureFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<UpgradeDependencyFailureFault, __BaseException>
  );
}
export interface ModifyReplicationSubnetGroupMessage {
  ReplicationSubnetGroupIdentifier: string | undefined;
  ReplicationSubnetGroupDescription?: string | undefined;
  SubnetIds: string[] | undefined;
}
export interface ModifyReplicationSubnetGroupResponse {
  ReplicationSubnetGroup?: ReplicationSubnetGroup | undefined;
}
export declare class SubnetAlreadyInUse extends __BaseException {
  readonly name: "SubnetAlreadyInUse";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<SubnetAlreadyInUse, __BaseException>);
}
export interface ModifyReplicationTaskMessage {
  ReplicationTaskArn: string | undefined;
  ReplicationTaskIdentifier?: string | undefined;
  MigrationType?: MigrationTypeValue | undefined;
  TableMappings?: string | undefined;
  ReplicationTaskSettings?: string | undefined;
  CdcStartTime?: Date | undefined;
  CdcStartPosition?: string | undefined;
  CdcStopPosition?: string | undefined;
  TaskData?: string | undefined;
}
export interface ModifyReplicationTaskResponse {
  ReplicationTask?: ReplicationTask | undefined;
}
export interface MoveReplicationTaskMessage {
  ReplicationTaskArn: string | undefined;
  TargetReplicationInstanceArn: string | undefined;
}
export interface MoveReplicationTaskResponse {
  ReplicationTask?: ReplicationTask | undefined;
}
export interface RebootReplicationInstanceMessage {
  ReplicationInstanceArn: string | undefined;
  ForceFailover?: boolean | undefined;
  ForcePlannedFailover?: boolean | undefined;
}
export interface RebootReplicationInstanceResponse {
  ReplicationInstance?: ReplicationInstance | undefined;
}
export interface RefreshSchemasMessage {
  EndpointArn: string | undefined;
  ReplicationInstanceArn: string | undefined;
}
export interface RefreshSchemasResponse {
  RefreshSchemasStatus?: RefreshSchemasStatus | undefined;
}
export declare const ReloadOptionValue: {
  readonly DATA_RELOAD: "data-reload";
  readonly VALIDATE_ONLY: "validate-only";
};
export type ReloadOptionValue =
  (typeof ReloadOptionValue)[keyof typeof ReloadOptionValue];
export interface TableToReload {
  SchemaName: string | undefined;
  TableName: string | undefined;
}
export interface ReloadReplicationTablesMessage {
  ReplicationConfigArn: string | undefined;
  TablesToReload: TableToReload[] | undefined;
  ReloadOption?: ReloadOptionValue | undefined;
}
export interface ReloadReplicationTablesResponse {
  ReplicationConfigArn?: string | undefined;
}
export interface ReloadTablesMessage {
  ReplicationTaskArn: string | undefined;
  TablesToReload: TableToReload[] | undefined;
  ReloadOption?: ReloadOptionValue | undefined;
}
export interface ReloadTablesResponse {
  ReplicationTaskArn?: string | undefined;
}
export interface RemoveTagsFromResourceMessage {
  ResourceArn: string | undefined;
  TagKeys: string[] | undefined;
}
export interface RemoveTagsFromResourceResponse {}
export interface RunFleetAdvisorLsaAnalysisResponse {
  LsaAnalysisId?: string | undefined;
  Status?: string | undefined;
}
export declare const StartReplicationMigrationTypeValue: {
  readonly RELOAD_TARGET: "reload-target";
  readonly RESUME_PROCESSING: "resume-processing";
  readonly START_REPLICATION: "start-replication";
};
export type StartReplicationMigrationTypeValue =
  (typeof StartReplicationMigrationTypeValue)[keyof typeof StartReplicationMigrationTypeValue];
export interface StartDataMigrationMessage {
  DataMigrationIdentifier: string | undefined;
  StartType: StartReplicationMigrationTypeValue | undefined;
}
export interface StartDataMigrationResponse {
  DataMigration?: DataMigration | undefined;
}
export interface StartExtensionPackAssociationMessage {
  MigrationProjectIdentifier: string | undefined;
}
export interface StartExtensionPackAssociationResponse {
  RequestIdentifier?: string | undefined;
}
export interface StartMetadataModelAssessmentMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
}
export interface StartMetadataModelAssessmentResponse {
  RequestIdentifier?: string | undefined;
}
export interface StartMetadataModelConversionMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
}
export interface StartMetadataModelConversionResponse {
  RequestIdentifier?: string | undefined;
}
export declare const OriginTypeValue: {
  readonly SOURCE: "SOURCE";
  readonly TARGET: "TARGET";
};
export type OriginTypeValue =
  (typeof OriginTypeValue)[keyof typeof OriginTypeValue];
export interface StartMetadataModelExportAsScriptMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
  Origin: OriginTypeValue | undefined;
  FileName?: string | undefined;
}
export interface StartMetadataModelExportAsScriptResponse {
  RequestIdentifier?: string | undefined;
}
export interface StartMetadataModelExportToTargetMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
  OverwriteExtensionPack?: boolean | undefined;
}
export interface StartMetadataModelExportToTargetResponse {
  RequestIdentifier?: string | undefined;
}
export interface StartMetadataModelImportMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
  Origin: OriginTypeValue | undefined;
  Refresh?: boolean | undefined;
}
export interface StartMetadataModelImportResponse {
  RequestIdentifier?: string | undefined;
}
export interface StartRecommendationsRequest {
  DatabaseId: string | undefined;
  Settings: RecommendationSettings | undefined;
}
export interface StartReplicationMessage {
  ReplicationConfigArn: string | undefined;
  StartReplicationType: string | undefined;
  PremigrationAssessmentSettings?: string | undefined;
  CdcStartTime?: Date | undefined;
  CdcStartPosition?: string | undefined;
  CdcStopPosition?: string | undefined;
}
export interface StartReplicationResponse {
  Replication?: Replication | undefined;
}
export declare const StartReplicationTaskTypeValue: {
  readonly RELOAD_TARGET: "reload-target";
  readonly RESUME_PROCESSING: "resume-processing";
  readonly START_REPLICATION: "start-replication";
};
export type StartReplicationTaskTypeValue =
  (typeof StartReplicationTaskTypeValue)[keyof typeof StartReplicationTaskTypeValue];
export interface StartReplicationTaskMessage {
  ReplicationTaskArn: string | undefined;
  StartReplicationTaskType: StartReplicationTaskTypeValue | undefined;
  CdcStartTime?: Date | undefined;
  CdcStartPosition?: string | undefined;
  CdcStopPosition?: string | undefined;
}
export interface StartReplicationTaskResponse {
  ReplicationTask?: ReplicationTask | undefined;
}
export interface StartReplicationTaskAssessmentMessage {
  ReplicationTaskArn: string | undefined;
}
export interface StartReplicationTaskAssessmentResponse {
  ReplicationTask?: ReplicationTask | undefined;
}
export declare class KMSFault extends __BaseException {
  readonly name: "KMSFault";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<KMSFault, __BaseException>);
}
export interface StartReplicationTaskAssessmentRunMessage {
  ReplicationTaskArn: string | undefined;
  ServiceAccessRoleArn: string | undefined;
  ResultLocationBucket: string | undefined;
  ResultLocationFolder?: string | undefined;
  ResultEncryptionMode?: string | undefined;
  ResultKmsKeyArn?: string | undefined;
  AssessmentRunName: string | undefined;
  IncludeOnly?: string[] | undefined;
  Exclude?: string[] | undefined;
  Tags?: Tag[] | undefined;
}
export interface StartReplicationTaskAssessmentRunResponse {
  ReplicationTaskAssessmentRun?: ReplicationTaskAssessmentRun | undefined;
}
export interface StopDataMigrationMessage {
  DataMigrationIdentifier: string | undefined;
}
export interface StopDataMigrationResponse {
  DataMigration?: DataMigration | undefined;
}
export interface StopReplicationMessage {
  ReplicationConfigArn: string | undefined;
}
export interface StopReplicationResponse {
  Replication?: Replication | undefined;
}
export interface StopReplicationTaskMessage {
  ReplicationTaskArn: string | undefined;
}
export interface StopReplicationTaskResponse {
  ReplicationTask?: ReplicationTask | undefined;
}
export interface TestConnectionMessage {
  ReplicationInstanceArn: string | undefined;
  EndpointArn: string | undefined;
}
export interface TestConnectionResponse {
  Connection?: Connection | undefined;
}
export interface UpdateSubscriptionsToEventBridgeMessage {
  ForceMove?: boolean | undefined;
}
export interface UpdateSubscriptionsToEventBridgeResponse {
  Result?: string | undefined;
}
export declare const ImportCertificateMessageFilterSensitiveLog: (
  obj: ImportCertificateMessage
) => any;
export declare const ModifyDataMigrationMessageFilterSensitiveLog: (
  obj: ModifyDataMigrationMessage
) => any;
export declare const ModifyDataMigrationResponseFilterSensitiveLog: (
  obj: ModifyDataMigrationResponse
) => any;
export declare const ModifyEndpointMessageFilterSensitiveLog: (
  obj: ModifyEndpointMessage
) => any;
export declare const ModifyEndpointResponseFilterSensitiveLog: (
  obj: ModifyEndpointResponse
) => any;
export declare const StartDataMigrationResponseFilterSensitiveLog: (
  obj: StartDataMigrationResponse
) => any;
export declare const StopDataMigrationResponseFilterSensitiveLog: (
  obj: StopDataMigrationResponse
) => any;
